import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleOrdinal, max, format, extent } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import ReactDropdown from 'react-dropdown';
import { Dropdown } from './Dropdown';
import { ColorLegend } from './ColorLegend';

const width = 960;
const menuHeight = 30;
const height = 500 - menuHeight;
const margin = { top: 20, right: 200, bottom: 165, left: 90 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

const attributes = [
  { value: 'Retentions', label: 'Retentions' },
  { value: 'Retentions Rate', label: 'Retentions Rate' },
  { value: 'Attendance Rate', label: 'Attendance Rate' },
  { value: 'Average # of Absences', label: 'Average # of Absences' },
  { value: 'Absent 10 or more days', label: 'Absent 10 or more days' },
  { value: 'Unexcused > 9 days', label: 'Unexcused > 9 days' },
];

const getLabel = value => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};

const App = () => {
  const data = useData();

  const initialXAttribute = 'Chronically_Absent';
  const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const xValue = d => d[xAttribute];
  const xAxisLabel = getLabel(xAttribute);

  const initialYAttribute = 'Retentions';
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  const yValue = d => d[yAttribute];
  const yAxisLabel = getLabel(yAttribute);

  const initialradiusAttribute = 'Retentions Rate';
  const [radiusAttribute, setradiusAttribute] = useState(initialradiusAttribute);
  const radiusValue = d => d[radiusAttribute];
  
  const colorValue = d => d.Year;
	const colorLegendLabel = 'Year';



  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.1s');
  const xAxisTickFormat = tickValue => siFormat(tickValue)

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0 ]);

  const radiusScale = scaleLinear()
    .domain(extent(data, radiusValue))
    .range([2, 8]); //range of circle sizes
  
  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range(['#183A2B', '#235740', '#2F7455', '#3B916A', '#47AE80','#60BE94','#7DCAA7']);
  
  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">X</span>
        <ReactDropdown
          options={attributes}
          value={xAttribute}
          onChange={({ value }) => setXAttribute(value)}
        />
        <span className="dropdown-label">Y</span>
        <ReactDropdown
          options={attributes}
          value={yAttribute}
          onChange={({ value }) => setYAttribute(value)}
        />
        <span className="dropdown-label">Size</span>
        <ReactDropdown
          options={attributes}
          value={radiusAttribute}
          onChange={({ value }) => setradiusAttribute(value)}
        />
      </div>
				<svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
        	<AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={5}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
              {yAxisLabel}
          </text>
          <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
          <g transform={`translate(${innerWidth + 60}, 60)`}>
          <text
            x={35}
            y={-25}
            className="axis-label"
            textAnchor="middle"
          >
            {colorLegendLabel}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickSize={10}
            tickTextOffset={12}
            //tickSize={circleScale(circleValue(d))}
            colorScale={colorScale}
          />
          </g>
          
          
          <Marks
            data={data}
            xScale={xScale}
            xValue={xValue}
            yScale={yScale}
            yValue={yValue}
            colorScale={colorScale}
          	colorValue={colorValue}
            circleScale={radiusScale}
          	circleValue={radiusValue}
            tooltipFormat={xAxisTickFormat}
          />
        </g>
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
